@@ -18,69 +18,68 @@
 
 #' DSD Moving Generator
 #'
-#' Creates an evolving DSD that consists of several \code{MGC}s.
+#' Creates an evolving DSD that consists of several [MGC], each representing a moving cluster.
 #'
 #' This DSD is able to generate complex datasets that are able to evolve over a
-#' period of time.  Its behavior is determined by the \code{MGC}s it is
-#' composed of.
+#' period of time. Its behavior is determined by as set of [MGC]s, each representing
+#' a moving cluster.
+#'
+#' @family DSD
 #'
-#' @aliases DSD_MG DSD_MovingGenerator MovingGenerator add_cluster get_clusters
-#' remove_cluster
 #' @param dimension the dimension of the DSD object
-#' @param ... initial set of \code{MGC}s
-#' @param x A \code{DSD_MG} object.
-#' @param c The cluster that should be added to the \code{DSD_MG} object.
+#' @param ... initial set of [MGC]s
+#' @param x A `DSD_MG` object.
+#' @param c The cluster that should be added to the `DSD_MG` object.
 #' @param i The index of the cluster that should be removed from the
-#' \code{DSD_MG} object.
-#' @param label,labels integer representing the cluster label. \code{NA}
+#' `DSD_MG` object.
+#' @param label,labels integer representing the cluster label. `NA`
 #' represents noise.  If labels are not specified, then each new cluster gets a
 #' new label.
-#' @param description An optional string used by \code{print} to describe the
+#' @param description An optional string used by `print()` to describe the
 #' data generator.
+#' @seealso [MGC] for types of moving clusters.
 #' @author Matthew Bolanos
-#' @seealso \code{\link{MGC_Function}}, \code{\link{MGC_Linear}},
-#' \code{\link{MGC_Noise}}, \code{\link{MGC_Random}} for details on the
-#' different \code{MGC} objects.
 #' @examples
-#'
 #' ### create an empty DSD_MG
 #' stream <- DSD_MG(dim = 2)
 #' stream
 #'
 #' ### add two clusters
-#' c1 <- MGC_Random(density=50, center=c(50,50), parameter=1, randomness = )
+#' c1 <- MGC_Random(density = 50, center = c(50, 50), parameter = 1)
 #' add_cluster(stream, c1)
 #' stream
 #'
-#' c2 <- MGC_Noise(density=1, range=rbind(c(-20,120), c(-20,120)))
+#' c2 <- MGC_Noise(density = 1, range = rbind(c(-20, 120), c(-20, 120)))
 #' add_cluster(stream, c2)
 #' stream
 #'
 #' get_clusters(stream)
-#' plot(stream, xlim=c(-20,120), ylim=c(-20,120))
+#' get_points(stream, n = 5)
+#' plot(stream, xlim = c(-20,120), ylim = c(-20, 120))
 #'
-#' \dontrun{
-#' animate_data(stream, n=5000, xlim=c(-20,120), ylim=c(-20,120))
+#' if (interactive()) {
+#' animate_data(stream, n = 5000, xlim = c(-20, 120), ylim = c(-20, 120))
 #' }
 #'
 #' ### remove cluster 1
-#' remove_cluster(stream,1)
+#' remove_cluster(stream, 1)
+#' stream
 #'
 #' get_clusters(stream)
-#' plot(stream, xlim=c(-20,120), ylim=c(-20,120))
+#' plot(stream, xlim = c(-20, 120), ylim = c(-20, 120))
 #'
 #' ### create a more complicated cluster structure (using 2 clusters with the same
 #' ### label to form an L shape)
-#' stream <- DSD_MG(dim=2,
-#'   MGC_Static(density=10, center=c(.5,.2), par=c(.4,.2), shape=MGC_Shape_Block),
-#'   MGC_Static(density=10, center=c(.6,.5), par=c(.2,.4), shape=MGC_Shape_Block),
-#'   MGC_Static(density=5, center=c(.39,.53), par=c(.16,.35), shape=MGC_Shape_Block),
-#'   MGC_Noise(density=1, range=rbind(c(0,1), c(0,1))),
-#'   labels= c(1, 1, 2, NA)
+#' stream <- DSD_MG(dim = 2,
+#'   MGC_Static(density = 10, center = c(.5, .2),   par = c(.4, .2),   shape = Shape_Block),
+#'   MGC_Static(density = 10, center = c(.6, .5),   par = c(.2, .4),   shape = Shape_Block),
+#'   MGC_Static(density = 5,  center = c(.39, .53), par = c(.16, .35), shape = Shape_Block),
+#'   MGC_Noise( density = 1,  range = rbind(c(0,1), c(0,1))),
+#'   labels = c(1, 1, 2, NA)
 #'   )
+#' stream
 #'
-#' plot(stream, xlim=c(0,1), ylim=c(0,1))
-#'
+#' plot(stream, xlim = c(0, 1), ylim = c(0, 1))
 #'
 #' ### simulate the clustering of a splitting cluster
 #' c1 <- MGC_Linear(dim = 2, keyframelist = list(
@@ -98,14 +97,12 @@
 #' stream <- DSD_MG(dim = 2, c1, c2)
 #' stream
 #'
-#' dbstream <- DSC_DBSTREAM(r=10, lambda=0.1)
-#'
-#' \dontrun{
-#' purity <- animate_cluster(dbstream, stream, n=2500, type="both",
-#'   xlim=c(-10,120), ylim=c(-10,120), evaluationMeasure="purity", horizon=100)
+#' dbstream <- DSC_DBSTREAM(r = 20, lambda = 0.1)
+#' if (interactive()) {
+#' purity <- animate_cluster(dbstream, stream, n = 2500, type = "micro",
+#'   xlim = c(-10, 120), ylim = c(-10, 120), measure = "purity", horizon = 100)
 #' }
-#'
-#' @export DSD_MG
+#' @export
 DSD_MG <-
   function(dimension = 2,
     ...,
@@ -117,7 +114,7 @@ DSD_MG <-
     x <- structure(
       list(description = description,
         RObj = dsd_MG_refClass$new(d = dimension)),
-      class = c("DSD_MG", "DSD_R", "DSD_data.frame", "DSD")
+      class = c("DSD_MG", "DSD_R", "DSD")
     )
 
     l <- list(...)
@@ -131,14 +128,17 @@ DSD_MG <-
   }
 
 #' @rdname DSD_MG
+#' @export
 add_cluster <- function(x, c, label = NULL)
   UseMethod("add_cluster")
 
 #' @rdname DSD_MG
+#' @export
 get_clusters <- function(x)
   UseMethod("get_clusters")
 
 #' @rdname DSD_MG
+#' @export
 remove_cluster <- function(x, i)
   UseMethod("remove_cluster")
 
@@ -162,8 +162,6 @@ dsd_MG_refClass <- setRefClass(
   ),
 )
 
-
-
 dsd_MG_refClass$methods(
   add_cluster = function(c, label = NULL) {
     if (c$RObj$dimension != dimension)
@@ -180,17 +178,15 @@ dsd_MG_refClass$methods(
     labels <<- append(labels, label)
   },
 
-
-
-
   get_points = function(n,
-    cluster = FALSE,
-    outlier = FALSE) {
+    info = FALSE) {
     if (length(clusters) == 0)
       stop("DSD_MG does not contain any clusters!")
 
-    if (cluster)
+    # only allocate if cluster info is requested
+    if (info)
       a <- integer(n)
+
     data <- matrix(NA_real_, nrow = n, ncol = dimension)
 
     j <- 0L
@@ -235,9 +231,8 @@ dsd_MG_refClass$methods(
             }
           ))
 
-        if (cluster) {
+        if (info)
           a[(j + 1):(j + k)] <- labels[clusterOrder]
-        }
       }
 
       t <<- t + k / pointsPerSecond
@@ -246,46 +241,39 @@ dsd_MG_refClass$methods(
 
     data <- data.frame(data)
 
-    if (cluster)
-      attr(data, "cluster") <- a
+    if (info)
+      data[['.class']] <- a
 
     data
   }
 )
 
+#' @export
 get_points.DSD_MG <- function(x,
   n = 1,
-  outofpoints = c("stop", "warn", "ignore"),
-  cluster = FALSE,
-  class = FALSE,
-  outlier = FALSE,
+  info = TRUE,
   ...) {
   .nodots(...)
 
-  d <- x$RObj$get_points(n, cluster = TRUE)
-
-  a <- attr(d, "cluster")
-  if (!cluster)
-    attr(d, "cluster") <- NULL
-
-  if (class)
-    d <- cbind(d, class = a)
-
-  d
-
+  x$RObj$get_points(n, info = info)
 }
 
+#' @rdname DSD_MG
+#' @export
 add_cluster.DSD_MG <- function(x, c, label = NULL) {
   ### name noise NA unless specified otherwise
   if (is.null(label) && is(c, "MGC_Noise"))
     label <- NA
   x$RObj$add_cluster(c, label)
-}
+  invisible(x)
+  }
 
+#' @export
 reset_stream.DSD_MG <- function(dsd, pos = 1) {
   dsd$RObj$t <- pos
 }
 
+#' @export
 print.DSD_MG <- function(x, ...) {
   #NextMethod()
   cat(.line_break(paste(x$description)))
@@ -293,7 +281,7 @@ print.DSD_MG <- function(x, ...) {
   cat(
     paste(
       'With',
-      length(na.omit(unique(x$RObj$labels))),
+      length(x$RObj$clusters),
       'clusters',
       'in',
       x$RObj$dimension,
@@ -304,11 +292,14 @@ print.DSD_MG <- function(x, ...) {
   )
 }
 
+#' @export
 get_clusters.DSD_MG <- function(x) {
   x$RObj$clusters
 }
 
+#' @export
 remove_cluster.DSD_MG  <- function(x, i) {
   x$RObj$clusters[[i]] <- NULL
   x$RObj$labels <- x$RObj$labels[-i]
+  invisible(x)
 }
